package com.gic.auth.service.outer.impl;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.UserDTO;
import com.gic.auth.service.UserApiService;
import com.gic.commons.util.EntityUtil;
import com.gic.auth.entity.TabUser;
import com.gic.enterprise.error.ErrorCode;
import com.gic.auth.service.UserService;
import com.gic.store.utils.valid.ValidUtil;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * @author guojx
 * @date 2019/7/16 6:55 PM
 */
@Service("userApiService")
public class UserApiServiceImpl implements UserApiService{
    @Autowired
    private UserService userService;
    @Override
    public ServiceResponse<Integer> saveUser(UserDTO userDTO) {
        //valid param
        ServiceResponse paramResult = ValidUtil.allCheckValidate(userDTO, UserDTO.SaveUserValid.class);
        if (!paramResult.isSuccess()) {
            return paramResult;
        }
        if (userService.isPhoneRepeat(null, userDTO.getPhoneNumber())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "手机号码不能重复");
        }

        userDTO.setCreateTime(new Date());
        userDTO.setUpdateTime(new Date());
        userDTO.setStatus(1);
        return ServiceResponse.success(userService.saveUser(userDTO));
    }

    @Override
    public ServiceResponse editUser(UserDTO userDTO) {
        //valid param
        ServiceResponse paramResult = ValidUtil.allCheckValidate(userDTO, UserDTO.EditUserValid.class);
        if (!paramResult.isSuccess()) {
            return paramResult;
        }
        TabUser tabUser = userService.getUserById(userDTO.getUserId());
        if (tabUser == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "用户ID输入有误");
        }
        if (userService.isPhoneRepeat(userDTO.getUserId(), userDTO.getPhoneNumber())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "手机号码不能重复");
        }
        userDTO.setUpdateTime(new Date());
        userService.editUser(userDTO);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<UserDTO> getUserById(Integer userId) {
        TabUser tabUser = userService.getUserById(userId);
        if (tabUser == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "用户ID输入有误");
        }
        return ServiceResponse.success(EntityUtil.changeEntityNew(UserDTO.class, tabUser));
    }

    @Override
    public ServiceResponse<UserDTO> getUserByEnterpriseId(Integer enterpriseId) {
        TabUser tabUser = userService.getUserByEnterpriseId(enterpriseId);
        if (enterpriseId == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID输入有误");
        }
        return ServiceResponse.success(EntityUtil.changeEntityNew(UserDTO.class, tabUser));
    }

    @Override
    public ServiceResponse<List<UserDTO>> listUserByPhoneNumber(String phoneNumber) {
        List<TabUser> list = this.userService.listAllUserByPhoneNumber(phoneNumber);
        if(CollectionUtils.isNotEmpty(list)){
            return ServiceResponse.success(EntityUtil.changeEntityListByJSON(UserDTO.class, list));
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<UserDTO> login(String phoneNumber, Integer enterpriseId, String password) {
        TabUser user = this.userService.login(phoneNumber, enterpriseId, password);
        return ServiceResponse.success(EntityUtil.changeEntityByJSON(UserDTO.class, user));
    }
}
